<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <source>Missing root rights</source>
        <comment>Dialog title</comment>
        <translation>Keine Root-Rechte</translation>
    </message>
    <message>
        <source>Guymager needs to be started with root rights in order to perform acquisitions. You are not root and thus won&apos;t be able to acquire devices.
Continue anyway?</source>
        <translation>Guymager muss mit Root-Rechten gestartet werden um Akquisitionen ausführen zu können. Sie haben keine Root-Rechte und daher werden Sie keine Geräte akquirieren können.
Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Deleting %1</source>
        <translation>Lösche %1</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <source>Linux dd raw image</source>
        <translation>Linux dd-Image</translation>
    </message>
    <message>
        <source>Expert Witness Format, sub-format %1</source>
        <translation>EWF-Format, Unterformat %1</translation>
    </message>
    <message>
        <source>Advanced forensic image</source>
        <translation>AFF format</translation>
    </message>
    <message>
        <source>Guymager cannot scan the devices connected to this computer.</source>
        <translation>Guymager kann die angeschlossenen Geräte nicht abfragen.</translation>
    </message>
    <message>
        <source>The selected scan method (&quot;%1&quot;) is not available. Do you want to try another scan method?</source>
        <translation>Die gewählte Abfragemethode (&quot;%1&quot;) steht nicht zur Verfügung. Möchten Sie eine  andere Methode versuchen?</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <source>Try method &quot;%1&quot;</source>
        <translation>Methode &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Creation of a clone</source>
        <translation>Erstellen eines Klons</translation>
    </message>
    <message>
        <source>Linux split dd raw image</source>
        <translation>Linux dd-Image, gesplittet</translation>
    </message>
</context>
<context>
    <name>t_DeviceListModel</name>
    <message>
        <source>Linux
device</source>
        <comment>Column of device table</comment>
        <translation>Linux
Gerät</translation>
    </message>
    <message>
        <source>Model</source>
        <comment>Column of device table</comment>
        <translation>Modell</translation>
    </message>
    <message>
        <source>Serial
nr.</source>
        <comment>Column of device table</comment>
        <translation>Serien-
nummer</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>Column of device table</comment>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Remarks</source>
        <comment>Column of device table</comment>
        <translation>Bemerkungen</translation>
    </message>
    <message>
        <source>State</source>
        <comment>Column of device table</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Hidden
Areas</source>
        <comment>Column of device table</comment>
        <translation>Versteckte
Bereiche</translation>
    </message>
    <message>
        <source>Bad
sectors</source>
        <comment>Column of device table</comment>
        <translation>Defekte
Sektoren</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>Column of device table</comment>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Average
Speed
[MB/s]</source>
        <comment>Column of device table</comment>
        <translation>Mittlere
Geschw.
[MB/s]</translation>
    </message>
    <message>
        <source>Time
remaining</source>
        <comment>Column of device table</comment>
        <translation>Restzeit</translation>
    </message>
    <message>
        <source>FIFO queues
usage
[%]</source>
        <comment>Column of device table</comment>
        <translation>FIFO-
Belegung
[%]</translation>
    </message>
</context>
<context>
    <name>t_DlgAbort</name>
    <message>
        <source>Do you want to abort the acquisition of %1?</source>
        <translation>Möchten Sie die Akquisition von %1 abbrechen?</translation>
    </message>
    <message>
        <source>Delete partial image files</source>
        <translation>Partielle Image-Dateien löschen</translation>
    </message>
    <message>
        <source>Do you want to abort the verification of %1?</source>
        <translation>Möchten Sie die Verifizierung von %1 abbrechen?</translation>
    </message>
    <message>
        <source>Abort?</source>
        <comment>Dialog title</comment>
        <translation>Abbrechen?</translation>
    </message>
</context>
<context>
    <name>t_DlgAcquire</name>
    <message>
        <source>EwfCaseNumber</source>
        <translation>Fallnummer</translation>
    </message>
    <message>
        <source>EwfEvidenceNumber</source>
        <translation>Asservatennummer</translation>
    </message>
    <message>
        <source>EwfExaminer</source>
        <translation>Bearbeiter</translation>
    </message>
    <message>
        <source>EwfDescription</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>EwfNotes</source>
        <translation>Notizen</translation>
    </message>
    <message>
        <source>DestImageFilename</source>
        <translation>Image-Dateiname (ohne Endung)</translation>
    </message>
    <message>
        <source>DestInfoFilename</source>
        <translation>Info-Dateiname (ohne Endung)</translation>
    </message>
    <message>
        <source>File format</source>
        <translation>Dateiformat</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <source>Configuration flag WriteToDevNull is set!</source>
        <translation>Konfigurationsparameter WriteToDevNull ist gesetzt!</translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <comment>Dialog title</comment>
        <translation>Zielverzeichnis auswählen</translation>
    </message>
    <message>
        <source>The filenames contain special characters which are not allowed. Guymager suggests the following changes:
	Image filename: %1
	Info filename: %2
Do you accept these changes?</source>
        <translation>Die Dateinamen enthalten unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgende Namen vor:
	Image-Dateiname: %1
	Info-Dateiname: %2
Sind Sie mit diesen Änderungen einverstanden?</translation>
    </message>
    <message>
        <source>(file extension %1)</source>
        <translation>(Datei-Endung %1)</translation>
    </message>
    <message>
        <source>Special characters</source>
        <comment>Dialog title</comment>
        <translation>Sonderzeichen</translation>
    </message>
    <message>
        <source>DestImageDirectory</source>
        <translation>Image-Verzeichnis</translation>
    </message>
    <message>
        <source>DestInfoDirectory</source>
        <translation>Info-Verzeichnis</translation>
    </message>
    <message>
        <source>...</source>
        <comment>The directory browse button</comment>
        <translation>...</translation>
    </message>
    <message>
        <source>Access denied</source>
        <comment>Dialog title</comment>
        <translation>Kein Zugriff</translation>
    </message>
    <message>
        <source>HashCalcMD5</source>
        <translation>MD5 berechnen</translation>
    </message>
    <message>
        <source>HashCalcSHA256</source>
        <translation>SHA-256 berechnen</translation>
    </message>
    <message>
        <source>HashVerifySrc</source>
        <translation>Quellmedium nach Akquisition erneut lesen und verifizieren (benötigt die doppelte Zeit)</translation>
    </message>
    <message>
        <source>HashVerifyDst</source>
        <translation>Image nach Akquisition verifizieren (benötigt die doppelte Zeit)</translation>
    </message>
    <message>
        <source>Hash calculation / verification</source>
        <translation>Hash-Berechnung und Verifizierung</translation>
    </message>
    <message>
        <source>Guymager cannot write to the directory
	%1
This may be due to insufficient access rights or unsupported filename characters. Please choose another directory.</source>
        <translation>Der Schreibzugriff auf das Verzeichnis	%1schlug fehl. Dies könnte an unzureichenden Zugriffsrechten oder an Sonderzeichen im Dateinamen liegen. Bitte wählen Sie ein anderes Verzeichnis.</translation>
    </message>
    <message>
        <source>Local device, cannot be written</source>
        <translation>Lokales Gerät, nicht beschreibbar</translation>
    </message>
    <message>
        <source>Too small</source>
        <translation>Zu klein</translation>
    </message>
    <message>
        <source>In use</source>
        <translation>Wird bereits benutzt</translation>
    </message>
    <message>
        <source>Ok for cloning</source>
        <translation>Bereit zum Klonen</translation>
    </message>
    <message>
        <source>The info filename contains special characters which are not allowed. Guymager suggests the following changes:
	%1
Do you accept these changes?</source>
        <translation>Der Info-Dateiname enthält unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgenden Namen vor:	 %1
Sind Sie mit diesen Änderungen einverstanden?</translation>
    </message>
    <message>
        <source>Files exist</source>
        <comment>Dialog title</comment>
        <translation>Dateien existieren bereits</translation>
    </message>
    <message>
        <source>The image or info files already exist. Do you want to overwrite them?</source>
        <translation>Die Image- oder Info-Dateien existieren bereits. Möchten Sie sie überschreiben?</translation>
    </message>
    <message>
        <source>Clone %1</source>
        <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
        <translation>Gerät %1 klonen</translation>
    </message>
    <message>
        <source>Acquire image of %1</source>
        <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
        <translation>Image von %1 erstellen</translation>
    </message>
    <message>
        <source>Device to be cloned</source>
        <translation>Zu klonendes Gerät</translation>
    </message>
    <message>
        <source>Used in another clone operation</source>
        <translation>Durch andere Klon-Operation belegt</translation>
    </message>
    <message>
        <source>SplitFileSize</source>
        <translation>Splitgröße</translation>
    </message>
    <message>
        <source>SplitFileSwitch</source>
        <translation>Image splitten</translation>
    </message>
    <message>
        <source>(file extension %1 or %2)</source>
        <translation>(Datei-Endung %1 oder %2)</translation>
    </message>
    <message>
        <source>Incorrect value</source>
        <comment>Dialog title</comment>
        <translation>Ungültiger Wert</translation>
    </message>
    <message>
        <source>The split file size &quot;%1&quot; is not valid. Only positive numbers can be entered.</source>
        <translation>Die Grösse %1 für die Split-Dateien ist ungültig. Bitte geben Sie einen positiven Wert ein.</translation>
    </message>
    <message>
        <source>The info file already exists. Do you want to overwrite it?</source>
        <translation>Die Info-Datei existiert bereits. Möchten Sie sie überschreiben?</translation>
    </message>
    <message>
        <source>The split size for EWF files must be in the range %1 - %2 MiB.</source>
        <translation type="obsolete">Die Split-Grösse von EWF-Dateien muss im Bereich %1 - %2 MiB liegen.</translation>
    </message>
    <message>
        <source>SplitFileUnit</source>
        <translation> </translation>
    </message>
    <message>
        <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
        <translation>Die Split-Grösse für das gewählte Datei-Format muss im Bereich %1 MiB - %2 EiB liegen.</translation>
    </message>
    <message>
        <source>The split size for the configured EWF format must be in the range %1 - %2 MiB.For bigger files, switch to Encase6 format or later (see Guymager configuration file, parameter EwfFormat).</source>
        <translation type="obsolete">Die Split-Grösse für das konfigurierte EWF-Format muss im Bereich %1 MiB - %2 MiB liegen. Grössere Dateien sind ab dem Format Encase6 möglich (siehe Guymager Konfigurationsdatei, Parameter EwfFormat).</translation>
    </message>
    <message>
        <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or later (see Guymager configuration file, parameter EwfFormat).</source>
        <translation>Die Split-Grösse für das konfigurierte EWF-Format muss im Bereich %1 MiB - %2 MiB liegen. Grössere Dateien sind ab dem Format Encase6 möglich (siehe Guymager Konfigurationsdatei, Parameter EwfFormat).</translation>
    </message>
</context>
<context>
    <name>t_DlgAutoExit</name>
    <message>
        <source>Abort</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <source>Exit now</source>
        <translation>Jetzt beenden</translation>
    </message>
    <message>
        <source>All acquisitions have ended.
Guymager will exit automatically in %1 seconds.</source>
        <translation>Alle Akquisitionen wurden abgeschlossen.
Guymager beendet sich automatisch in %1 Sekunden.</translation>
    </message>
</context>
<context>
    <name>t_DlgDirSel</name>
    <message>
        <source>New directory</source>
        <translation>Neues Verzeichnis</translation>
    </message>
    <message>
        <source>Remove directory</source>
        <translation>Verzeichnis entfernen</translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <comment>Dialog title</comment>
        <translation>Zielverzeichnis auswählen</translation>
    </message>
    <message>
        <source>NewDirectory</source>
        <comment>Name of the new directory that will be created</comment>
        <translation>NeuesVerzeichnis</translation>
    </message>
</context>
<context>
    <name>t_DlgMessage</name>
    <message>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
</context>
<context>
    <name>t_Info</name>
    <message>
        <source>Command executed: %1</source>
        <translation>Ausgeführter Befehl: %1</translation>
    </message>
    <message>
        <source>No information can be displayed as a timeout occured while executing the command.</source>
        <translation>Der Befehl benötigte zu lange; keine Informationen vorhanden.</translation>
    </message>
    <message>
        <source>Information returned:</source>
        <translation>Ausgabe:</translation>
    </message>
</context>
<context>
    <name>t_InfoField</name>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Sector size</source>
        <translation>Sektorgröße</translation>
    </message>
    <message>
        <source>Image file</source>
        <translation>Image-Datei</translation>
    </message>
    <message>
        <source>Info file</source>
        <translation>Info-Datei</translation>
    </message>
    <message>
        <source>Current speed</source>
        <translation>Aktuelle Geschwindigkeit</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <source>Hash calculation</source>
        <translation>Hash-Berechnung</translation>
    </message>
    <message>
        <source>Source verification</source>
        <translation>Verifikation Quellmedium</translation>
    </message>
    <message>
        <source>Started</source>
        <comment>Start timestamp and running time</comment>
        <translation>Läuft seit</translation>
    </message>
    <message>
        <source>MD5 and SHA-256</source>
        <comment>Both hashes are calculated</comment>
        <translation>MD5 und SHA-256</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>off</source>
        <comment>Hash calculation is off</comment>
        <translation>aus</translation>
    </message>
    <message>
        <source>Image verification</source>
        <translation>Verifikation Image</translation>
    </message>
    <message>
        <source>on</source>
        <comment>Display that verification is on</comment>
        <translation>ein</translation>
    </message>
    <message>
        <source>off</source>
        <comment>Display that verification is off</comment>
        <translation>aus</translation>
    </message>
    <message>
        <source>Additional state info</source>
        <translation>Status-Zusatzinformation</translation>
    </message>
</context>
<context>
    <name>t_MainWindow</name>
    <message>
        <source>Local device</source>
        <translation>Lokales Gerät</translation>
    </message>
    <message>
        <source>Idle</source>
        <translation>--</translation>
    </message>
    <message>
        <source>Cleanup</source>
        <translation>Aufräumen</translation>
    </message>
    <message>
        <source>Finished</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>Aborted - Error: Reason is &apos;none&apos;</source>
        <translation>Abbruch - Fehler &quot;Reason none&quot;</translation>
    </message>
    <message>
        <source>Aborted by user</source>
        <translation>Abbruch durch Benutzer</translation>
    </message>
    <message>
        <source>Aborted - Image file write error</source>
        <translation>Abbruch - Image-Schreibfehler</translation>
    </message>
    <message>
        <source>Aborted - Device read error</source>
        <translation>Abbruch - Lesefehler</translation>
    </message>
    <message>
        <source>&amp;Rescan</source>
        <translation>&amp;Auffrischen</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>There are active acquisitions. Do you really want to abort them and quit?</source>
        <translation>GUYMAGER hat noch Akquisitionen laufen. Möchten Sie diese abbrechen und das Programm verlassen?</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation>Debug-Informationen</translation>
    </message>
    <message>
        <source>About GUYMAGER</source>
        <comment>Dialog title</comment>
        <translation>Über GUYMAGER</translation>
    </message>
    <message>
        <source>GUYMAGER is a Linux-based forensic imaging tool

Version: %1
Compilation timestamp: %2
Compiled with gcc %3
Using libewf %4
Using libguytools %5</source>
        <translation type="obsolete">GUYMAGER ist ein Linux-basierter, forensischer Imager

Version: %1
Zeitstempel der Kompilation: %2
Kompiliert mit gcc %3
Benutzt libewf %4
Benutzt libguytools %5</translation>
    </message>
    <message>
        <source>About Qt</source>
        <comment>Dialog title</comment>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>Exit GUYMAGER</source>
        <comment>Dialog title</comment>
        <translation>GUYMAGER verlassen</translation>
    </message>
    <message>
        <source>&amp;Devices</source>
        <translation>&amp;Geräte</translation>
    </message>
    <message>
        <source>&amp;Misc</source>
        <comment>Menu entry</comment>
        <translation>&amp;Verschiedenes</translation>
    </message>
    <message>
        <source>Debug</source>
        <comment>Menu entry</comment>
        <translation>Debug</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>Menu entry</comment>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>About &amp;GUYMAGER</source>
        <comment>Menu entry</comment>
        <translation>Über &amp;GUYMAGER</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <comment>Menu entry</comment>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>Acquisition running</source>
        <translation>Akquisition läuft</translation>
    </message>
    <message>
        <source>Verification running</source>
        <translation>Verifikation läuft</translation>
    </message>
    <message>
        <source>Device disconnected, acquisition paused</source>
        <translation>Gerät abgeschaltet, Akquisition unterbrochen</translation>
    </message>
    <message>
        <source>Device disconnected, verification paused</source>
        <translation>Gerät abgeschaltet, Verifikation unterbrochen</translation>
    </message>
    <message>
        <source>Finished - Verified &amp; ok</source>
        <translation>Fertig - Verifiziert &amp; ok</translation>
    </message>
    <message>
        <source>Finished - Verification failed</source>
        <translation>Fertig- Verifizierung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Aborted - Image file verify error</source>
        <translation>Abgebrochen - Fehler bei Verifizierung</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Media info string for informing about hidden areas (HPA/DCO)</comment>
        <translation>k.A.</translation>
    </message>
    <message>
        <source>No</source>
        <comment>Media info string for informing about hidden areas (HPA/DCO)</comment>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Yes</source>
        <comment>Media info string for informing about hidden areas (HPA/DCO)</comment>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Rescan devices and update table</source>
        <translation>Geräte neu einlesen und Tabelle auffrischen</translation>
    </message>
    <message>
        <source>Add special device</source>
        <comment>Menu entry</comment>
        <translation>Sondergerät hinzufügen</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <source>Invalid device</source>
        <comment>Dialog title</comment>
        <translation>Ungültiges Gerät</translation>
    </message>
    <message>
        <source>Manually added special device</source>
        <translation>Manuell hinzugefügtes Sondergerät</translation>
    </message>
    <message>
        <source>Device alrady contained</source>
        <comment>Dialog title</comment>
        <translation>Gerät bereits vorhanden</translation>
    </message>
    <message>
        <source>The selected file or device already is contained in the table.</source>
        <translation>Das Gerät bzw. die Datei ist bereits in der Tabelle enthalten.</translation>
    </message>
    <message>
        <source>The device or file cannot be selected because its size is unknown.</source>
        <translation>Das Gerät bzw. die Datei kann nicht ausgewählt werden da seine Grösse unbekannt ist.</translation>
    </message>
    <message>
        <source>The device or file cannot be selected because it contains 0 bytes.</source>
        <translation>Das Gerät bzw. die Datei kann nicht ausgewählt werden da seine Grösse 0 Byte beträgt.</translation>
    </message>
    <message>
        <source>Used in clone operation</source>
        <translation>Belegt durch Klon-Operation</translation>
    </message>
    <message>
        <source>Aborting...</source>
        <translation>Abbruch angefragt...</translation>
    </message>
    <message>
        <source>none</source>
        <comment>column hidden areas</comment>
        <translation>keine</translation>
    </message>
    <message>
        <source>unknown</source>
        <comment>column hidden areas</comment>
        <translation>nicht feststellbar</translation>
    </message>
    <message>
        <source>Exit after acquisitions completed</source>
        <translation>Guymager nach Abschluss aller Akquisitionen beenden</translation>
    </message>
    <message>
        <source>Aborted - Info file write error</source>
        <translation>Abbruch - Schreibfehler Info-Datei</translation>
    </message>
    <message>
        <source>Aborted - Acquisition start failure</source>
        <translation>Abbruch - Startfehler Akquisition</translation>
    </message>
    <message>
        <source>(not used as Guymager currently is configured to use its own EWF module)</source>
        <translation>(inaktiv, da das Guymager-interne EWF-Modul konfiguriert ist)</translation>
    </message>
    <message>
        <source>GUYMAGER is a Linux-based forensic imaging tool

Version: %1
Compilation timestamp: %2
Compiled with gcc %3
Linked with libewf %4 %5
Linked with libguytools %6</source>
        <translation>GUYMAGER ist ein Linux-basierter, forensischer Imager

Version: %1
Zeitstempel der Kompilation: %2
Kompiliert mit gcc %3
Benutzt libewf %4 %5
Benutzt libguytools %6</translation>
    </message>
</context>
<context>
    <name>t_Table</name>
    <message>
        <source>Local Device - cannot be acquired</source>
        <translation>Lokales Gerät - kann nicht akquiriert werden</translation>
    </message>
    <message>
        <source>Info</source>
        <comment>Context menu</comment>
        <translation>Info</translation>
    </message>
    <message>
        <source>Device info</source>
        <comment>Dialog title</comment>
        <translation>Geräte-Informationen</translation>
    </message>
    <message>
        <source>GUYMAGER ACQUISITION INFO FILE</source>
        <comment>Info file</comment>
        <translation>GUYMAGER INFO-DATEI ZUR AKQUISITION</translation>
    </message>
    <message>
        <source>Guymager</source>
        <comment>Info file</comment>
        <translation>Guymager</translation>
    </message>
    <message>
        <source>Device information</source>
        <comment>Info file</comment>
        <translation>Geräte-Informationen</translation>
    </message>
    <message>
        <source>Finished successfully</source>
        <comment>Info file</comment>
        <translation>Erfolgreich beendet</translation>
    </message>
    <message>
        <source>(with %1 bad sectors)</source>
        <comment>Info file, may be appended to &apos;finished successfully&apos; message</comment>
        <translation>(mit %1 defekten Sektoren)</translation>
    </message>
    <message>
        <source>Aborted by user</source>
        <comment>Info file</comment>
        <translation>Abbruch durch Benutzer</translation>
    </message>
    <message>
        <source>Aborted because of image write error</source>
        <comment>Info file</comment>
        <translation>Abbruch wegen Fehler beim Schreiben der Image-Datei</translation>
    </message>
    <message>
        <source>Aborted, strange reason (%1)</source>
        <comment>Info file</comment>
        <translation>Abbruch, unbekannter Grund (%1)</translation>
    </message>
    <message>
        <source>Strange state (%1)</source>
        <comment>Info file</comment>
        <translation>Unbekannter Zustand (%1)</translation>
    </message>
    <message>
        <source>State: %1</source>
        <comment>Info file</comment>
        <translation>Status: %1</translation>
    </message>
    <message>
        <source>During verification, %1 bad sectors have been encountered. The sector numbers are:</source>
        <comment>Info file</comment>
        <translation>Während der MD5-Verifizierung wurden %1 defekte Sektoren festgestellt. Die Sektor-Nummern sind:</translation>
    </message>
    <message>
        <source>During acquisition, %1 bad sectors have been encountered. They have been replaced by zeroed sectors. The sector numbers are:</source>
        <comment>Info file</comment>
        <translation>Während der Akquisition wurden %1 defekte Sektoren festgestellt. Die Sektor-Nummern sind:</translation>
    </message>
    <message>
        <source>No bad sectors encountered during verification.</source>
        <comment>Info file</comment>
        <translation>Bei der Verifizierung wurden keine defekte Sektoren entdeckt.</translation>
    </message>
    <message>
        <source>No bad sectors encountered during acquisition.</source>
        <comment>Info file</comment>
        <translation>Bei der Akquisition wurden keine defekte Sektoren entdeckt.</translation>
    </message>
    <message>
        <source>(during acquisition)</source>
        <comment>Info file</comment>
        <translation>(während der Akquisition)</translation>
    </message>
    <message>
        <source>(ISO format YYYY-MM-DD HH:MM:SS)</source>
        <translation>(ISO-Format JJJJ-MM-TT SS:MM:ss)</translation>
    </message>
    <message>
        <source>Acquisition aborted before start of verification</source>
        <translation>Akquisition vor Beginn der MD5-Verifizierung abgebrochen</translation>
    </message>
    <message>
        <source>Linux device:: %1</source>
        <comment>Info file</comment>
        <translation>Linux-Gerät:: %1</translation>
    </message>
    <message>
        <source>Device size:: %1 (%2)</source>
        <comment>Info file</comment>
        <translation>Grösse:: %1 (%2)</translation>
    </message>
    <message>
        <source>Acquisition started:: %1</source>
        <comment>Info file</comment>
        <translation>Beginn Akquisition:: %1</translation>
    </message>
    <message>
        <source>Verification started:: %1</source>
        <comment>Info file</comment>
        <translation>Beginn MD5-Verifikation:: %1</translation>
    </message>
    <message>
        <source>Ended:: %1 (%2 hours, %3 minutes and %4 seconds)</source>
        <comment>Info file</comment>
        <translation>Ende:: %1 (%2 Stunden, %3 Minuten und %4 Sekunden)</translation>
    </message>
    <message>
        <source>Acquisition speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
        <comment>Info file</comment>
        <translation>Geschwindigkeit Akquisition:: %1 MByte/s (%2 Stunden, %3 Minuten und %4 Sekunden)</translation>
    </message>
    <message>
        <source>--</source>
        <comment>Info file</comment>
        <translation>--</translation>
    </message>
    <message>
        <source>MD5 hash:: %1</source>
        <comment>Info file</comment>
        <translation>MD5-Hash:: %1</translation>
    </message>
    <message>
        <source>Version:: %1</source>
        <comment>Info file</comment>
        <translation>Version:: %1</translation>
    </message>
    <message>
        <source>Compilation timestamp:: %1</source>
        <comment>Info file</comment>
        <translation>Zeitstempel der Kompilation:: %1</translation>
    </message>
    <message>
        <source>Compiled with:: %1 %2</source>
        <comment>Info file</comment>
        <translation>Kompiliert mit:: %1 %2</translation>
    </message>
    <message>
        <source>libewf version:: %1</source>
        <comment>Info file</comment>
        <translation>Version libewf:: %1</translation>
    </message>
    <message>
        <source>libguytools version:: %1</source>
        <comment>Info file</comment>
        <translation>Version libguytools:: %1</translation>
    </message>
    <message>
        <source>Verification speed:: %1 MByte/s (%2 hours, %3 minutes and %4 seconds)</source>
        <comment>Info file</comment>
        <translation>Geschwindigkeit MD5-Verifizierung:: %1 MByte/s (%2 Stunden, %3 Minuten und %4 Sekunden)</translation>
    </message>
    <message>
        <source>Hash calculation:: off</source>
        <comment>Info file</comment>
        <translation>Hash-Berechnung:: aus</translation>
    </message>
    <message>
        <source>Source verification:: on</source>
        <comment>Info file</comment>
        <translation>Verifikation Quellmedium:: ein</translation>
    </message>
    <message>
        <source>Source verification:: off</source>
        <comment>Info file</comment>
        <translation>Verifikation Quellmedium:: aus</translation>
    </message>
    <message>
        <source>(during source verification)</source>
        <comment>Info file</comment>
        <translation>(während der Verifikation des Quellmediums)</translation>
    </message>
    <message>
        <source>SHA256 hash:: %1</source>
        <comment>Info file</comment>
        <translation>SHA256-Hash:: %1</translation>
    </message>
    <message>
        <source>Hash calculation:: MD5 and SHA-256</source>
        <comment>Info file</comment>
        <translation>Hash-Berechnung:: MD5 und SHA-256</translation>
    </message>
    <message>
        <source>Hash calculation:: MD5</source>
        <comment>Info file</comment>
        <translation>Hash-Berechnung:: MD5</translation>
    </message>
    <message>
        <source>Hash calculation:: SHA-256</source>
        <comment>Info file</comment>
        <translation>Hash-Berechnung:: SHA-256</translation>
    </message>
    <message>
        <source>Image path and file name:: %1</source>
        <comment>Info file</comment>
        <translation>Image-Pfad und Datei:: %1</translation>
    </message>
    <message>
        <source>Info  path and file name:: %1</source>
        <comment>Info file</comment>
        <translation>Info -Pfad und Datei:: %1</translation>
    </message>
    <message>
        <source>Image verification:: on</source>
        <comment>Info file</comment>
        <translation>Verifikation Image-Datei:: ein</translation>
    </message>
    <message>
        <source>Image verification:: off</source>
        <comment>Info file</comment>
        <translation>Verifikation Image-Datei:: aus</translation>
    </message>
    <message>
        <source>Aborted because of image read error during verification</source>
        <comment>Info file</comment>
        <translation>Abbruch wegen Image-Lesefehler während der Verifizierung</translation>
    </message>
    <message>
        <source>MD5 hash verified source:: %1</source>
        <comment>Info file</comment>
        <translation>MD5-Hash Quellmedium verifiziert:: %1</translation>
    </message>
    <message>
        <source>MD5 hash verified image:: %1</source>
        <comment>Info file</comment>
        <translation>MD5-Hash Image verifiziert:: %1</translation>
    </message>
    <message>
        <source>SHA256 hash verified source:: %1</source>
        <comment>Info file</comment>
        <translation>SHA256-Hash Quellmedium verifiziert:: %1</translation>
    </message>
    <message>
        <source>SHA256 hash verified image:: %1</source>
        <comment>Info file</comment>
        <translation>SHA256-Hash Image verifiziert:: %1</translation>
    </message>
    <message>
        <source>Source verification OK. The device delivered the same data during acquisition and verification.</source>
        <translation>Verifizierung Quellmedium in Ordnung. Das Gerät lieferte die gleichen Daten während der Akquisition und der Verifikation.</translation>
    </message>
    <message>
        <source>Source verification FAILED. The device didn&apos;t deliver the same data during acquisition and verification. Check if the defect sector list was the same during acquisition and verification (see above).</source>
        <translation>Verifizierung Quellmedium schlug fehl. Das Gerät lieferte unterschiedliche Daten während der Akquisition und der Verifikation. Versuchen Sie ev. eine weitere Akquisition. Überprüfen Sie, ob die Liste der defekten Sektoren für Akquisition und Verifikation gleich ist (siehe oben).</translation>
    </message>
    <message>
        <source>Image verification OK. The image contains exactely the data that was written.</source>
        <translation>Verifizierung Image in Ordnung. Das Image enhält genau die Daten, die bei der Akquisition geschrieben wurden.</translation>
    </message>
    <message>
        <source>Image verification FAILED. The data in the image is different from what was written.</source>
        <translation>Verifizierung Image schlug fehl: Die Daten im Image sind andere als die, die bei der Akquisition geschrieben wurden.</translation>
    </message>
    <message>
        <source>Maybe you try to acquire the device again.</source>
        <translation>Versuchen Sie eine erneute Akquisition.</translation>
    </message>
    <message>
        <source>Remove special device</source>
        <comment>Context menu</comment>
        <translation>Sondergerät entfernen</translation>
    </message>
    <message>
        <source>Image meta data</source>
        <comment>Info file</comment>
        <translation>Image Meta-Daten </translation>
    </message>
    <message>
        <source> - file extension is %1</source>
        <comment>Info file</comment>
        <translation> - mit Datei-Endung %1</translation>
    </message>
    <message>
        <source>Acquire image</source>
        <comment>Context menu</comment>
        <translation>Image-Datei erstellen</translation>
    </message>
    <message>
        <source>Clone device</source>
        <comment>Context menu</comment>
        <translation>Gerät klonen</translation>
    </message>
    <message>
        <source>Abort</source>
        <comment>Context menu</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Acquisition</source>
        <comment>Info file</comment>
        <translation>Akquisition</translation>
    </message>
    <message>
        <source>Format:: %1</source>
        <comment>Info file</comment>
        <translation>Format:: %1</translation>
    </message>
    <message>
        <source>Device used for cloning - cannot be acquired</source>
        <translation>Gerät durch Klon-Operation belegt - kann nicht akquiriert werden</translation>
    </message>
    <message>
        <source>Generated image files and their MD5 hashes</source>
        <comment>Info file</comment>
        <translation>Erezugte Image-Dateien und ihre MD5-Hashwerte</translation>
    </message>
    <message>
        <source>No MD5 hashes available (the select EWF format does not support image file hashes)</source>
        <translation>Keine MD5-Hashes verfügbar (das ausgewählte EWF-Format unterstützt das Hashen der Image-Dateien nicht)</translation>
    </message>
    <message>
        <source>No MD5 hashes available (image verification checkbox was switched off)</source>
        <translation>Keine MD5-Hashes verfügbar (das Häkchen zur Image-Verifikation war nicht gesetzt)</translation>
    </message>
    <message>
        <source>No MD5 hashes available (configuration parameter CalcImageFileMD5 is off)</source>
        <translation>Keine MD5-Hashes verfügbar (der Konfigurationsparameter CalcImageFileMD5 ist abgeschaltet)</translation>
    </message>
    <message>
        <source>Cannot be acquired - see additional state info field</source>
        <translation>Kann nicht akquiriert werden - siehe Status-Zusatzinformation</translation>
    </message>
</context>
<context>
    <name>t_ThreadScan</name>
    <message>
        <source>Cannot scan devices</source>
        <comment>Dialog title</comment>
        <translation>Geräteabfrage funktioniert nicht</translation>
    </message>
    <message>
        <source>None of the device scan methods worked. Exiting now.</source>
        <translation>Keine der Methoden zum Abfragen der angeschlossenen Geräte funktionierte. Guymager wird nun beendet.</translation>
    </message>
</context>
</TS>
